##
##  jj.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         jj
Summary:      Git-Compatible Version Control System (VCS)
URL:          https://martinvonz.github.io/jj/
Vendor:       Martin von Zweigbergk
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        SCM
License:      Apache
Version:      0.29.0
Release:      20250508

#   list of sources
Source0:      https://github.com/martinvonz/jj/archive/refs/tags/v%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, rust
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Jujutsu is a powerful version control system for software projects.
    It uses Git repositories via libgit2 as a storage layer to serve
    and track content, making it compatible with many of your favorite
    Git-based tools.

%track
    prog jj = {
        version   = %{version}
        url       = https://github.com/martinvonz/jj/releases
        regex     = tree/v(\d+\.\d+\.\d+)
    }

%prep
    %setup -q -n jj-%{version}

%build
    #   build program
    HOME=`pwd`
    cargo build --release

%install
    #   create installation hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin

    #   install program
    %{l_shtool} install -c -s -m 755 \
        target/release/jj $RPM_BUILD_ROOT%{l_prefix}/bin/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

